// When setting up this script, the following conditions must be meet.
// The user/device/zone must contain a location called "Scripting Test Location". 
//     At this location the security policies should restrict the device/user to only those actions allowed.
//     For real world applications, the "Scripting Test Location" location may be setup to not allow manual changes in or out of it.
//
// A "Location Assignment Policy" should be published so "Scripting Test Location" is a valid security location.
// A "Scripting Policy" should be published with this script.
//    "Scripting Policy" should be triggered 
//                           "Enforcement of this Policy", 
//                           "Time Tigger" value of 1 minute or for all network events or both


// Debug messages ONLY work through Rule Scripting test interface or
// with debug output tools (like Dbgview.exe) when ZESService/ZESUser has been started with HKLM/Software/Novell-ZES/Log/DbgTracing is set to 1
// this will NOT run in standard WSH (you would have to replace them with WScript.Echo (which won't run in the policy script)
Action.Trace("Script Process Watcher has started");



// Uncommentment for debugging purposes:
//          When a script is called, it is given information about why it was triggered. 
//                     DisplayTriggerParameters();
//
//          If you want to see the set of policies being applied:
//                     DisplayEffectivePolicies();
//
//          If you want to see the set of Locations assigned to the box:
//                     DisplayAssignedLocation();
//
//          If you want to see the set of Network/Configuration Locations assigned to the box:
//                     DisplayNetworkLocations();
//
//          If you want to see the current Security Location and the reason this location was chosen
// 


var locationName = "Scripting Test Location";
var requiredApp = new Array("calc.exe");
var locationChangePriority = 100;


var bFoundAppTriggerLocation="False"; 

list = Query.AssignedLocationList;
Action.Trace("Assigned location list count is: " + list.count);
for (idx = 0; idx < list.Count; idx++)
{
loc = list.Item(idx);
if (loc.Name.toLowerCase() == locationName.toLowerCase())
{
    bFoundAppTriggerLocation = "True";
}
//NOTE:  Uncomment out the next line if you want to see the list of security locations assigned to this device
//DisplayAssignedLocation(loc);
}

Action.Trace("Looking for application to be running when in location: \"" + locationName + "\"");
Action.Trace("Check for finding this location in the list of Assigned Locations returned: " + bFoundAppTriggerLocation);

if (bFoundAppTriggerLocation == "True")
{

    if (Query.SecurityLocation.Name.toLowerCase() == locationName.toLowerCase())
    {
	Action.Trace("In the location requiring the application to run, so looking for the application: " + requiredApp);
	var foundAppRunning = false;

	for (i=0; i< requiredApp.length; i++) {

	    var proc = requiredApp[i].toLowerCase();

	    var e = new Enumerator (GetObject("winmgmts:").InstancesOf("Win32_process"));

	    for (; !e.atEnd(); e.moveNext()) {
		    var p = e.item ();
		    curproc = p.Name.toLowerCase();
		    if (curproc == proc) 
		    {
			Action.Trace("Found required application running: " + curproc);
			foundAppRunning = true;
			break;
		    }
	    }
	}

	Action.Trace("Check for required application returned: " + foundAppRunning);
	//the following if statement will send a warning message is the application is not running
	if (!foundAppRunning) Action.DisplayMessage("Application Checker:", "The following application is required to run in this security location: " + requiredApp, "error", 15);
	//the following if statement will start the application if it is not running
	if (!foundAppRunning)
	{
	var ret;
		ret = Action.Launch("user", false, requiredApp, "");
		Action.Trace("User: Launch " + requiredApp + ": " + ret);
	}
    }
    else
    {
	Action.Trace("Not in the location requiring the application check, so dropping out.");
    }
}
else
{
    Action.DisplayMessage("Application Checker", locationName  + " location has not been assigned to the device", "info", 15);
}


function DisplayChangeReason(ret) 
{
    Action.Trace("Reason : " + ret.Reason);
    Action.Trace("Producer: " + ret.Producer);
    Action.Trace("RuleId: " + ret.RuleId);
    Action.Trace("RuleName: " + ret.RuleName);
    Action.Trace("Level: " + ret.Level);
    DisplayAssignedLocation(ret.SecurityLocation);
}

function DisplayAssignedLocation(loc) 
{
    Action.Trace("Location = " + loc.Name);
    Action.Trace("Id = " + loc.Id);
    Action.Trace("Date Modified = " + loc.DateModified);
    Action.Trace("Order: " + loc.Order);
    Action.Trace("Mobile: " + loc.Mobile);
    Action.Trace("Allow Manual Change: " + loc.AllowsManualChange);
    Action.Trace("Show in menu: " + loc.ShowInMenu);
}


function DisplayNetworkLocation(loc) 
{
    Action.Trace("Location = " + loc.Name);
    Action.Trace("Id = " + loc.Id);
    Action.Trace("Date Modified = " + loc.DateModified);
    Action.Trace("Order: " + loc.Order);
    Action.Trace("Mobile: " + loc.Mobile);
}

function DisplayTriggerParameters()
{
    Action.Trace("");
    Action.Trace(" ******** Trigger Parameters ********* ");
    Action.Trace("");
    Action.Trace("Reason = " + Query.TriggerParameter("reason"));
    Action.Trace("Parameter Count = " + Query.TriggerParameterCount);
    for(var idx = 0; idx < Query.TriggerParameterCount; idx++)
    {
        Action.Trace("Parameter: " + Query.TriggerParameterName(idx) + " -> " + Query.TriggerParameterValue(idx));
    }
}

function DisplayEffectivePolicies()
{
    Action.Trace(" ******** Effective Policy List Access ****** ");
    var ret = Query.EffectivePolicyList();
    for(var i = 0; i < ret.Count; i++)
    {
        var pol = ret.Item(i);
        Action.Trace(" ******** Policy Information ********* ");
        Action.Trace("ID: " + pol.Id);
        Action.Trace("Version: " + pol.Version);
        Action.Trace("Name: " + pol.Name);
        Action.Trace("Type: " + pol.PolicyType);
        Action.Trace("Session: " + pol.Session);
    }
}

